@@ -7,16 +7,17 @@ import random
 import traceback
 
 from petisco.application.petisco import Petisco
+from petisco.domain.errors.critical_error import CriticalError
 from petisco.domain.errors.unknown_error import UnknownError
 from petisco.events.routing_key import RoutingKey
-from petisco.logger.interface_logger import INFO, ERROR
+from petisco.logger.interface_logger import ERROR, DEBUG, WARNING
 from petisco.events.event import Event
 from functools import wraps
 from meiga import Result, Failure
 from meiga.decorators import meiga
 
 from petisco.logger.log_message import LogMessage
-from petisco.notifier.domain.notifier_message import NotifierMessage
+from petisco.notifier.domain.notifier_exception_message import NotifierExceptionMessage
 from petisco.notifier.infrastructure.not_implemented_notifier import (
     NotImplementedNotifier,
 )
@@ -82,7 +83,7 @@ class _SubscriberHandler:
 
     def _log_nack_simulation(self, log_message: LogMessage):
         self.logger.log(
-            INFO,
+            WARNING,
             log_message.set_message(
                 f"Message rejected (Simulation rejecting {self.percentage_simulate_nack * 100}% of the messages)"
             ),
@@ -96,14 +97,16 @@ class _SubscriberHandler:
 
     def _log_filter_by_routing_key(self, log_message: LogMessage):
         self.logger.log(
-            INFO,
+            WARNING,
             log_message.set_message(
                 f"Message rejected (filtering by routing_key {self.filter_routing_key})"
             ),
         )
 
     def _log_invalid_event_format(self, log_message: LogMessage, body: Dict):
-        self.logger.log(INFO, log_message.set_message(f"Invalid event format: {body})"))
+        self.logger.log(
+            ERROR, log_message.set_message(f"Invalid event format: {body})")
+        )
 
     def __call__(self, func, *args, **kwargs):
         @wraps(func)
@@ -123,7 +126,7 @@ class _SubscriberHandler:
             log_message = LogMessage(layer="subscriber", operation=f"{func.__name__}")
 
             self.logger.log(
-                INFO,
+                DEBUG,
                 log_message.set_message(
                     {"routing_key": method.routing_key, "body": json.loads(body)}
                 ),
@@ -152,26 +155,43 @@ class _SubscriberHandler:
             try:
                 result = run_subscriber(**kwargs)
             except Exception as exception:
-                result = Failure(UnknownError(exception))
+                result = Failure(
+                    UnknownError(
+                        exception=exception,
+                        input_parameters=kwargs if len(kwargs) > 0 else args,
+                        executor=f"{func.__name__} (Subscriber)",
+                        traceback=traceback.format_exc(),
+                    )
+                )
 
             if self.delay_after:
                 time.sleep(self.delay_after)
 
+            self.notify(result)
+
             if result is None or result.is_failure:
                 message = f"{result}: {traceback.format_exc()}"
                 self.logger.log(ERROR, log_message.set_message(message))
-                self.notifier.publish(
-                    NotifierMessage(
-                        title=f"Subscriber: {func.__name__}",
-                        message=f"{result}: {traceback.format_exc()}",
-                        info_petisco=Petisco.get_info(),
-                    )
-                )
                 ch.basic_nack(delivery_tag=method.delivery_tag)
             else:
                 ch.basic_ack(delivery_tag=method.delivery_tag)
 
         return wrapper
 
+    @meiga
+    def notify(self, result):
+        if result.is_failure:
+            error = result.value
+            if issubclass(error.__class__, CriticalError):
+                self.notifier.publish(
+                    NotifierExceptionMessage(
+                        exception=error.exception,
+                        executor=error.executor,
+                        input_parameters=error.input_parameters,
+                        traceback=error.traceback,
+                        info_petisco=Petisco.get_info(),
+                    )
+                )
+
 
 subscriber_handler = _SubscriberHandler
